@@ -31,7 +31,6 @@ import univention.admin.objects
 import univention.admin.uldap
 import univention.debug as ud
 import univention.logging
-import univention.uldap
 from univention.connector.adcache import ADCache
 from univention.dn import DN
 from univention.logging import Structured
@@ -88,11 +87,9 @@ def set_primary_group_user(connector, key, ucs_object):
     """check if correct primary group is set"""
     connector.set_primary_group_to_ucs_user(key, ucs_object)
 
+
 # compare functions
-
 # helper
-
-
 def dictonary_lowercase(dict_):
     if isinstance(dict_, dict):
         ndict = {}
@@ -123,9 +120,8 @@ def compare_lowercase(val1, val2):
     except Exception:  # FIXME: which exception is to be caught?
         return False
 
+
 # helper classes
-
-
 class configdb:
 
     def __init__(self, filename):
@@ -294,48 +290,52 @@ class attribute:
     """
     A mapping attribute description
 
-    :param ucs_attribute:
-    The property name of the object in UDM
+    :param ucs_attribute: The property name of the object in UDM
     :type ucs_attribute: str
 
-    :param ldap_attribute:
-    The LDAP attribute name of the object in UCS LDAP
+    :param ldap_attribute: The LDAP attribute name of the object in UCS LDAP
     :type ldap_attribute: str
 
-    :param con_attribute:
-    The LDAP attribute name of the object in AD LDAP
+    :param con_attribute: The LDAP attribute name of the object in AD LDAP
     :type con_attribute: str
 
-    :param con_other_attribute:
-    Further LDAP attribute name of the object in AD LDAP.
+    :param con_other_attribute: Further LDAP attribute name of the object in AD LDAP.
     :type con_other_attribute: str
 
-    :param required:
-    unused
+    :param required: unused
     :type required: bool
 
-    :param single_value:
-    Whether the attribute is single_value in the AD LDAP.
+    :param single_value: Whether the attribute is single_value in the AD LDAP.
     :type single_value: bool
 
-    :param compare_function:
-    A comparison function which compares raw ldap attribute values.
+    :param compare_function: A comparison function which compares raw ldap attribute values.
     :type compare_function: callable
 
-    :param mapping:
-    Mapping functions for (sync_to_ad, sync_to_ucs)
+    :param mapping: Mapping functions for (sync_to_ad, sync_to_ucs)
     :ptype mapping: tuple
 
-    :param reverse_attribute_check:
-    Make a reverse check of this mapping, if the mapping is not 1:1.
+    :param reverse_attribute_check: Make a reverse check of this mapping, if the mapping is not 1:1.
     :ptype reverse_attribute_check: bool
 
-    :param sync_mode:
-    The syncronization direction (read, write, sync)
+    :param sync_mode: The syncronization direction (read, write, sync)
     :ptype sync_mode: str
     """
 
-    def __init__(self, ucs_attribute='', ldap_attribute='', con_attribute='', con_other_attribute='', required=0, single_value=False, compare_function='', mapping=(), reverse_attribute_check=False, sync_mode='sync', con_depends='', con_attribute_encoding='UTF-8'):
+    def __init__(
+        self,
+        ucs_attribute='',
+        ldap_attribute='',
+        con_attribute='',
+        con_other_attribute='',
+        required=0,
+        single_value=False,
+        compare_function='',
+        mapping=(),
+        reverse_attribute_check=False,
+        sync_mode='sync',
+        con_depends='',
+        con_attribute_encoding='UTF-8',
+    ):
         self.ucs_attribute = ucs_attribute
         self.ldap_attribute = ldap_attribute
         self.con_attribute = con_attribute
@@ -376,32 +376,32 @@ class attribute:
 class property:
 
     def __init__(
-            self,
-            ucs_default_dn='',
-            con_default_dn='',
-            ucs_module='',
-            ucs_module_others=[],
-            sync_mode='',
-            scope='',
-            con_search_filter='',
-            ignore_filter=None,
-            match_filter=None,
-            allow_subtree=[],
-            allow_filter=None,
-            ignore_subtree=[],
-            con_create_objectclass=[],
-            con_create_attributes=[],
-            dn_mapping_function=[],
-            attributes=None,
-            ucs_create_functions=[],
-            post_con_create_functions=[],
-            post_con_modify_functions=[],
-            post_ucs_modify_functions=[],
-            post_attributes=None,
-            mapping_table=None,
-            position_mapping=[],
-            con_subtree_delete_objects=[]):
-
+        self,
+        ucs_default_dn='',
+        con_default_dn='',
+        ucs_module='',
+        ucs_module_others=[],
+        sync_mode='',
+        scope='',
+        con_search_filter='',
+        ignore_filter=None,
+        match_filter=None,
+        allow_subtree=[],
+        allow_filter=None,
+        ignore_subtree=[],
+        con_create_objectclass=[],
+        con_create_attributes=[],
+        dn_mapping_function=[],
+        attributes=None,
+        ucs_create_functions=[],
+        post_con_create_functions=[],
+        post_con_modify_functions=[],
+        post_ucs_modify_functions=[],
+        post_attributes=None,
+        mapping_table=None,
+        position_mapping=[],
+        con_subtree_delete_objects=[],
+    ):
         self.ucs_default_dn = ucs_default_dn
 
         self.con_default_dn = con_default_dn
@@ -467,7 +467,6 @@ class property:
 class ucs:
 
     def __init__(self, CONFIGBASENAME, _property, configRegistry, listener_dir, logfilename, debug_level):
-
         self.CONFIGBASENAME = CONFIGBASENAME
 
         self.configRegistry = configRegistry
@@ -1102,7 +1101,12 @@ class ucs:
             con_other_attribute = attributes.con_other_attribute
 
             changed_attributes = object.get('changed_attributes')
-            changed = not changed_attributes or con_attribute in changed_attributes or (con_other_attribute and con_other_attribute in changed_attributes) or attributes.con_depends in changed_attributes
+            changed = (
+                not changed_attributes
+                or con_attribute in changed_attributes
+                or (con_other_attribute and con_other_attribute in changed_attributes)
+                or attributes.con_depends in changed_attributes
+            )
 
             if changed or modtype == 'add':
                 log.trace("__set_values: Set: %s", con_attribute)
@@ -1124,7 +1128,12 @@ class ucs:
 
             changed_attributes = object.get('changed_attributes')
 
-            changed = not changed_attributes or con_attribute in changed_attributes or (con_other_attribute and con_other_attribute in changed_attributes) or post_attributes.con_depends in changed_attributes
+            changed = (
+                not changed_attributes
+                or con_attribute in changed_attributes
+                or (con_other_attribute and con_other_attribute in changed_attributes)
+                or post_attributes.con_depends in changed_attributes
+            )
             if changed or modtype == 'add':
                 log.trace("__set_values: Set: %s", con_attribute)
                 if post_attributes.reverse_attribute_check:
@@ -1164,7 +1173,6 @@ class ucs:
         return res
 
     def modify_in_ucs(self, property_type, object, module, position):
-
         ucs_object_dn = object.get('olddn', object['dn'])
         ucs_object = univention.admin.objects.get(module, None, self.lo, dn=ucs_object_dn, position='')
         self.__set_values(property_type, object, ucs_object)
@@ -1175,6 +1183,7 @@ class ucs:
         serverctrls = [PostReadControl(True, ['entryUUID', 'entryCSN'])]
         res = ucs_object.modify(serverctrls=serverctrls, response=response)
         if res:
+            object['dn'] = res
             for c in response.get('ctrls', []):
                 if c.controlType == PostReadControl.controlType:  # If the modify actually did something
                     entryUUID = c.entry['entryUUID'][0].decode('ASCII')
@@ -1327,9 +1336,11 @@ class ucs:
                         if old_ad_object.get(attr) != original_attributes.get(attr) and attr not in object['changed_attributes']:
                             object['changed_attributes'].append(attr)
                     if not (set(object['changed_attributes']) - self.irrelevant_attributes):
-                        if property_type == "user" \
-                           and self.configRegistry.is_false('connector/ad/mapping/user/password/disabled', True) \
-                           and not self.configRegistry.is_true('connector/ad/mapping/user/password/kinit', False):
+                        if (
+                            property_type == "user"
+                            and self.configRegistry.is_false('connector/ad/mapping/user/password/disabled', True)
+                            and not self.configRegistry.is_true('connector/ad/mapping/user/password/kinit', False)
+                        ):
                             if object['attributes'].get('pwdLastSet', [b'1'])[0] == b'0':
                                 log.debug("sync_to_ucs: pwdLastSet is 0. Do not ignore %r", original_object['dn'])
                             else:
@@ -1509,9 +1520,7 @@ class ucs:
                 return False
 
         def connecting_filter(filter, attributes):
-
             def walk(filter, attributes):
-
                 def split(filter):
                     opened = []
                     closed = []
@@ -1555,7 +1564,6 @@ class ucs:
                 return 0 not in walk(filter[1:], attributes)
 
         def subfilter(filter, attributes):
-
             if filter[0] == '(':
                 if not filter[-1] == ')':
                     raise ValueError(f"matching ) missing in filter: {filter}")
@@ -1581,8 +1589,11 @@ class ucs:
             log.debug("_ignore_object: ignore object without DN (key: %s)", key)
             return True  # ignore not existing object
 
-        if self.property[key].allow_subtree and not any(self._subtree_match(object['dn'], dn) for dn in self.property[key].allow_subtree) and (
-                not self.allow_subtree_ancestors or not any(DN(subtree_dn).endswith(object['dn']) for subtree_dn in self.property[key].allow_subtree)):
+        if (
+            self.property[key].allow_subtree
+            and not any(self._subtree_match(object['dn'], dn) for dn in self.property[key].allow_subtree)
+            and (not self.allow_subtree_ancestors or not any(DN(subtree_dn).endswith(object['dn']) for subtree_dn in self.property[key].allow_subtree))
+        ):
             log.debug('_ignore_object: ignore object because it is not in one of the allowed subtrees: [%r:%r]', key, object['dn'])
             return True
 
@@ -1682,7 +1693,7 @@ class ucs:
                     if dn_mapped == object[dntype]:
                         if self.lo_ad.base == dn_mapped[-len(self.lo_ad.base):] and len(self.lo_ad.base) > len(self.lo.base):
                             # Introduced via Bug #13745#c14 : avoid default _subtree_replace in case position_mapping was applied
-                            ud.debug(ud.LDAP, ud.INFO, "The dn %s is already converted to the AD base, don't do this again." % (dn_mapped,))
+                            log.debug("The dn %s is already converted to the AD base, don't do this again.", dn_mapped)
                         else:
                             dn_mapped = self._subtree_replace(object[dntype].lower(), self.lo.base.lower(), self.lo_ad.base)  # FIXME: lo_ad may change with other connectors
                 # write the correct upper and lower case back to the DN
